==> jc-1.4.0.tar.gz: java/lang/IllegalMonitorStateException.h <==
// public class java.lang.IllegalMonitorStateException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 252c536250e0b800 java_lang_IllegalMonitorStateException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_lang_IllegalMonitorStateException_H_
#define _JC_java_lang_IllegalMonitorStateException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_IllegalMonitorStateException$sub_refs	_jc_java_lang_IllegalMonitorStateException$sub_refs;
typedef struct _jc_java_lang_IllegalMonitorStateException$sub_nonrefs	_jc_java_lang_IllegalMonitorStateException$sub_nonrefs;
typedef struct _jc_java_lang_IllegalMonitorStateException$refs	_jc_java_lang_IllegalMonitorStateException$refs;
typedef struct _jc_java_lang_IllegalMonitorStateException$nonrefs	_jc_java_lang_IllegalMonitorStateException$nonrefs;
typedef struct _jc_java_lang_IllegalMonitorStateException$object	_jc_java_lang_IllegalMonitorStateException$object;

typedef struct _jc_java_lang_IllegalMonitorStateException$fields_struct	_jc_java_lang_IllegalMonitorStateException$fields_struct;
typedef const struct _jc_java_lang_IllegalMonitorStateException$vmethods	_jc_java_lang_IllegalMonitorStateException$vmethods;
typedef const struct _jc_java_lang_IllegalMonitorStateException$vtable	_jc_java_lang_IllegalMonitorStateException$vtable;
typedef const struct _jc_java_lang_IllegalMonitorStateException$vtype	_jc_java_lang_IllegalMonitorStateException$vtype;

// Class fields structure
struct _jc_java_lang_IllegalMonitorStateException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_IllegalMonitorStateException$fields_struct _jc_java_lang_IllegalMonitorStateException$class_fields;

// Constructors
extern void _jc_java_lang_IllegalMonitorStateException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_IllegalMonitorStateException$object *);
extern void _jc_java_lang_IllegalMonitorStateException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_IllegalMonitorStateException$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_IllegalMonitorStateException$vmethods {
};

// Vtable
struct _jc_java_lang_IllegalMonitorStateException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalMonitorStateException$vmethods	java_lang_IllegalMonitorStateException;
};

// Vtype
struct _jc_java_lang_IllegalMonitorStateException$vtype {
	_jc_type			type;
	_jc_java_lang_IllegalMonitorStateException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_IllegalMonitorStateException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_IllegalMonitorStateException$refs {
    _jc_java_lang_IllegalMonitorStateException$sub_refs	java_lang_IllegalMonitorStateException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_IllegalMonitorStateException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_IllegalMonitorStateException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalMonitorStateException$sub_nonrefs	java_lang_IllegalMonitorStateException;
};

// Object instance structure
struct _jc_java_lang_IllegalMonitorStateException$object {
	_jc_java_lang_IllegalMonitorStateException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_IllegalMonitorStateException$vtype	*vtype;
	_jc_java_lang_IllegalMonitorStateException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_IllegalMonitorStateException$vtype _jc_java_lang_IllegalMonitorStateException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_IllegalMonitorStateException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_IllegalMonitorStateException$class_object;

#endif	/* _JC_java_lang_IllegalMonitorStateException_H_ */

==> jc-1.4.6.tar.gz: java/lang/IllegalMonitorStateException.h <==
// public class java.lang.IllegalMonitorStateException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 252c536250e0b800 java_lang_IllegalMonitorStateException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_lang_RuntimeException

#include "java/lang/RuntimeException.h"

#ifndef _JC_java_lang_IllegalMonitorStateException_H_
#define _JC_java_lang_IllegalMonitorStateException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_IllegalMonitorStateException$sub_refs	_jc_java_lang_IllegalMonitorStateException$sub_refs;
typedef struct _jc_java_lang_IllegalMonitorStateException$sub_nonrefs	_jc_java_lang_IllegalMonitorStateException$sub_nonrefs;
typedef struct _jc_java_lang_IllegalMonitorStateException$refs	_jc_java_lang_IllegalMonitorStateException$refs;
typedef struct _jc_java_lang_IllegalMonitorStateException$nonrefs	_jc_java_lang_IllegalMonitorStateException$nonrefs;
typedef struct _jc_java_lang_IllegalMonitorStateException$object	_jc_java_lang_IllegalMonitorStateException$object;

typedef struct _jc_java_lang_IllegalMonitorStateException$fields_struct	_jc_java_lang_IllegalMonitorStateException$fields_struct;
typedef const struct _jc_java_lang_IllegalMonitorStateException$vmethods	_jc_java_lang_IllegalMonitorStateException$vmethods;
typedef const struct _jc_java_lang_IllegalMonitorStateException$vtable	_jc_java_lang_IllegalMonitorStateException$vtable;
typedef const struct _jc_java_lang_IllegalMonitorStateException$vtype	_jc_java_lang_IllegalMonitorStateException$vtype;

// Class fields structure
struct _jc_java_lang_IllegalMonitorStateException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_IllegalMonitorStateException$fields_struct _jc_java_lang_IllegalMonitorStateException$class_fields;

// Constructors
extern void _jc_java_lang_IllegalMonitorStateException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_IllegalMonitorStateException$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_IllegalMonitorStateException$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_IllegalMonitorStateException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_IllegalMonitorStateException$vmethods {
};

// Vtable
struct _jc_java_lang_IllegalMonitorStateException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalMonitorStateException$vmethods	java_lang_IllegalMonitorStateException;
};

// Vtype
struct _jc_java_lang_IllegalMonitorStateException$vtype {
	_jc_type			type;
	_jc_java_lang_IllegalMonitorStateException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_IllegalMonitorStateException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_IllegalMonitorStateException$refs {
    _jc_java_lang_IllegalMonitorStateException$sub_refs	java_lang_IllegalMonitorStateException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_IllegalMonitorStateException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_IllegalMonitorStateException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalMonitorStateException$sub_nonrefs	java_lang_IllegalMonitorStateException;
};

// Object instance structure
struct _jc_java_lang_IllegalMonitorStateException$object {
	_jc_java_lang_IllegalMonitorStateException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_IllegalMonitorStateException$vtype	*vtype;
	_jc_java_lang_IllegalMonitorStateException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_IllegalMonitorStateException$vtype _jc_java_lang_IllegalMonitorStateException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_IllegalMonitorStateException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_IllegalMonitorStateException$class_object;

#endif	/* _JC_java_lang_IllegalMonitorStateException_H_ */
